aboutsummaryrefslogtreecommitdiff
path: root/modules
diff options
context:
space:
mode:
authorNatasha Moongrave <natasha@256phi.eu>2026-02-16 10:32:13 +0100
committerNatasha Moongrave <natasha@256phi.eu>2026-02-16 10:32:13 +0100
commit0dccaa1a697967c8955f914a8af0c2f8a74917a5 (patch)
tree9e71eded158bb273b20c603e7fded4799fc0ec96 /modules
parentc31bccb5bc00f839beb4eb4f680c3a1533849e79 (diff)
added spotify to mun packages
Diffstat (limited to 'modules')
-rw-r--r--modules/home/i3wm/nord-blue/helix.nix72
1 files changed, 52 insertions, 20 deletions
diff --git a/modules/home/i3wm/nord-blue/helix.nix b/modules/home/i3wm/nord-blue/helix.nix
index ead3002..f0eba78 100644
--- a/modules/home/i3wm/nord-blue/helix.nix
+++ b/modules/home/i3wm/nord-blue/helix.nix
@@ -1,4 +1,4 @@
-{ pkgs, config, lib, ... }:
+{ pkgs, ... }:
{
programs.helix = {
@@ -23,7 +23,7 @@
auto-format = true;
end-of-line-diagnostics = "hint";
inline-diagnostics = {
- cursor-line = "hint";
+ cursor-line = "hint";
};
lsp = {
display-messages = true;
@@ -82,6 +82,16 @@
args = [ "start" ];
};
+ # HTML
+ "superhtml" = {
+ command = "${pkgs.superhtml}/bin/superhtml";
+ };
+
+ # CSS
+ "vscode-css-languageserver" = {
+ command = "${pkgs.vscode-css-languageserver}/bin/vscode-css-languageserver";
+ };
+
# Rust
"rust-analyzer" = {
command = "${pkgs.rust-analyzer}/bin/rust-analyzer";
@@ -101,13 +111,24 @@
"texlab" = {
command = "${pkgs.texlab}/bin/texlab";
};
- texlab.config.texlab.build = {
- onSave = true;
- forwardSearchAfter = true;
- executable = "latexmk";
- args = [ "-pdf" "-interaction=nonstopmode" "-synctex=1" "%f" ];
- };
+ texlab.config.texlab = {
+ build = {
+ onSave = true;
+ forwardSearchAfter = true;
+ };
+ chktext = {
+ onEdit = true;
+ };
+ forwardSearch = {
+ executable = "zathura";
+ args = [
+ "--synctex-forward"
+ "%l:1:%f"
+ "%p"
+ ];
+ };
+ };
# Markdown
"marksman" = {
@@ -121,6 +142,16 @@
auto-format = true;
}
{
+ name = "html";
+ language-servers = [ "superhtml" ];
+ auto-format = true;
+ }
+ {
+ name = "css";
+ language-servers = [ "vscode-css-languageserver" ];
+ auto-format = true;
+ }
+ {
name = "rust";
language-servers = [ "rust-analyzer" ];
auto-format = true;
@@ -143,24 +174,25 @@
{
name = "markdown";
language-servers = [ "marksman" ];
- auto-format = true;
+ auto-format = true;
}
];
};
};
-
home.packages = with pkgs; [
- zathura
- ripgrep
- fd
+ zathura
+ ripgrep
+ fd
- bash-language-server # LSP for Bash
- rust-analyzer # Rust LSP
+ bash-language-server # LSP for Bash
+ superhtml # LSP for HTML
+ vscode-css-languageserver # LSP for CSS
+ rust-analyzer # Rust LSP
llvmPackages_latest.lldb # lldb-dap for Rust
- pyright # Python LSP
- nil # Nix LSP
- texlab # LaTeX LSP
- marksman # Markdown LSP
+ pyright # Python LSP
+ nil # Nix LSP
+ texlab # LaTeX LSP
+ marksman # Markdown LSP
];
-} \ No newline at end of file
+}